@@ -1,10 +1,15 @@
 package OWL::DirectSemantics::Element::DataOneOf;
 
+BEGIN {
+	$OWL::DirectSemantics::Element::DataOneOf::AUTHORITY = 'cpan:TOBYINK';
+	$OWL::DirectSemantics::Element::DataOneOf::VERSION   = '0.000_03';
+};
+
 use 5.008;
-use common::sense;
+
+
+
 
-our $VERSION;
-BEGIN { $VERSION = "0.000_02"; }
 
 use Moose;
 
@@ -57,8 +62,15 @@ Toby Inkster E<lt>tobyink@cpan.orgE<gt>.
 
 =head1 COPYRIGHT
 
-Copyright 2011 Toby Inkster
+Copyright 2011-2012 Toby Inkster
 
 This library is free software; you can redistribute it and/or modify it
 under the same terms as Perl itself.
 
+=head1 DISCLAIMER OF WARRANTIES
+
+THIS PACKAGE IS PROVIDED "AS IS" AND WITHOUT ANY EXPRESS OR IMPLIED
+WARRANTIES, INCLUDING, WITHOUT LIMITATION, THE IMPLIED WARRANTIES OF
+MERCHANTIBILITY AND FITNESS FOR A PARTICULAR PURPOSE.
+
+
